@@ -287,7 +287,8 @@ grip_gesture_manager_finalize (GObject *object)
 {
   GripGestureManagerPrivate *priv = GRIP_GESTURE_MANAGER_GET_PRIVATE (object);
 
-  g_list_free_full (priv->classes, g_free);
+  g_list_foreach(priv->classes, (GFunc) g_free, NULL);
+  g_list_free(priv->classes);
 
   g_ptr_array_foreach (priv->devices, (GFunc) g_object_unref, NULL);
   g_ptr_array_unref (priv->devices);
